@@ -1,8 +1,8 @@
 use strict;
 use warnings;
 package Log::Dispatchouli;
-BEGIN {
-  $Log::Dispatchouli::VERSION = '2.005';
+{
+  $Log::Dispatchouli::VERSION = '2.009';
 }
 # ABSTRACT: a simple wrapper around Log::Dispatch
 
@@ -14,9 +14,122 @@ use Scalar::Util qw(blessed weaken);
 use String::Flogger;
 use Try::Tiny 0.04;
 
+require Log::Dispatchouli::Proxy;
+
 our @CARP_NOT = qw(Log::Dispatchouli::Proxy);
 
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 sub new {
   my ($class, $arg) = @_;
 
@@ -131,6 +244,21 @@ sub new {
 }
 
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 sub _join { shift; join q{ }, @{ $_[0] } }
 
 sub log {
@@ -173,6 +301,16 @@ sub log {
 }
 
 
+
+
+
+
+
+
+
+
+
+
 sub log_fatal {
   my ($self, @rest) = @_;
 
@@ -185,6 +323,16 @@ sub log_fatal {
 }
 
 
+
+
+
+
+
+
+
+
+
+
 sub log_debug {
   my ($self, @rest) = @_;
 
@@ -198,30 +346,89 @@ sub log_debug {
 }
 
 
+
+
+
+
+
+
+
+
 sub set_debug {
   return($_[0]->{debug} = $_[1] ? 1 : 0);
 }
 
 
+
+
+
+
+
+
 sub get_debug { return $_[0]->{debug} }
 
 
+
+
+
+
+
+
 sub clear_debug { }
 
 sub mute   { $_[0]{muted} = 1 }
 sub unmute { $_[0]{muted} = 0 }
 
 
+
+
+
+
+
+
+
+
 sub set_muted {
   return($_[0]->{muted} = $_[1] ? 1 : 0);
 }
 
 
+
+
+
+
+
+
 sub get_muted { return $_[0]->{muted} }
 
 
+
+
+
+
+
+
 sub clear_muted { }
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 
 sub get_prefix   { return $_[0]->{prefix}  }
 sub set_prefix   { $_[0]->{prefix} = $_[1] }
@@ -229,18 +436,60 @@ sub clear_prefix { $_[0]->unset_prefix     }
 sub unset_prefix { undef $_[0]->{prefix}   }
 
 
+
+
+
+
+
 sub ident { $_[0]{ident} }
 
 
+
+
+
+
+
+
+
+
 sub config_id { $_[0]{config_id} }
 
 
+
+
+
+
+
+
+
+
 sub string_flogger { 'String::Flogger' }
 
 
+
+
+
+
+
+
+
+
+
+
+
+
 sub env_prefix { return; }
 
 
+
+
+
+
+
+
+
+
+
 sub env_value {
   my ($self, $suffix) = @_;
 
@@ -255,6 +504,19 @@ sub env_value {
 }
 
 
+
+
+
+
+
+
+
+
+
+
+
+
+
 sub new_tester {
   my ($class, $arg) = @_;
   $arg ||= {};
@@ -272,6 +534,12 @@ sub new_tester {
 }
 
 
+
+
+
+
+
+
 sub events {
   Carp::confess "->events called on a logger not logging to self"
     unless $_[0]->{events};
@@ -280,6 +548,12 @@ sub events {
 }
 
 
+
+
+
+
+
+
 sub clear_events {
   Carp::confess "->events called on a logger not logging to self"
     unless $_[0]->{events};
@@ -289,6 +563,27 @@ sub clear_events {
 }
 
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 sub proxy {
   my ($self, $arg) = @_;
   $arg ||= {};
@@ -303,13 +598,58 @@ sub proxy {
 }
 
 
+
+
+
+
+
+
+
+
 sub parent { $_[0] }
 sub logger { $_[0] }
 
 
+
+
+
+
+
+
 sub dispatcher   { $_[0]->{dispatcher} }
 
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 sub is_debug { $_[0]->get_debug }
 sub is_info  { 1 }
 sub is_fatal { 1 }
@@ -324,18 +664,28 @@ use overload
 ;
 
 
+
+
+
+
+
+
+
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Log::Dispatchouli - a simple wrapper around Log::Dispatch
 
 =head1 VERSION
 
-version 2.005
+version 2.009
 
 =head1 SYNOPSIS
 
@@ -344,7 +694,7 @@ version 2.005
     facility  => 'daemon',
     to_stdout => $opt->{print},
     debug     => $opt->{verbose}
-  })
+  });
 
   $logger->log([ "There are %s items left to purge...", $stuff_left ]);
 
@@ -528,7 +878,7 @@ The above will log something like:
 
 To pass a prefix per-message:
 
-  $logger->log({ prefix => 'Sub-Item 234: ', 'error!' })
+  $logger->log({ prefix => 'Sub-Item 234: ' }, 'error!')
 
   # Logs: Batch 123: Sub-Item 234: error!
 
@@ -680,10 +1030,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Ricardo SIGNES.
+This software is copyright (c) 2014 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
